@@ -19,13 +19,13 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: pybcheck.py,v 1.3 1999/08/27 12:37:59 gobry Exp $
+# $Id: pybcheck.py,v 1.3 2000/03/13 13:45:35 fredgo Exp $
 
 import os, sys, string
-from Pyblio import Config
+from Pyblio import Config, Exceptions
 
 # check the arguments
-if len (sys.argv) < 2:
+if len (sys.argv) < 3:
     print "usage: pybcheck <file | directory>..."
     sys.exit (1)
 
@@ -36,7 +36,7 @@ broken = []
 Config.set ("bibtex/strict", 1)
 
 # we go over all the specified files
-for dir in sys.argv [1:]:
+for dir in sys.argv [2:]:
 
     # eventually expand directories to their content
     if os.path.isdir (dir):
@@ -56,7 +56,7 @@ for dir in sys.argv [1:]:
         try:
             b = bibopen (f)
             print "file `%s' is ok [%d entries]" % (f, len (b))
-        except (IOError, KeyError), err:
+        except (Exceptions.ParserError, KeyError), err:
             broken.append (str (err))
 
 # write the error messages (expected to be well formated)
